package Sah::SchemaR::unix::pathname;

our $DATE = '2020-05-27'; # DATE
our $VERSION = '0.011'; # VERSION

our $rschema = ["str",[{match=>"\\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z",prefilters=>["Path::expand_tilde","Path::strip_slashes"],summary=>"Filesystem path name on a Unix system","x.completion"=>["filename"]},{description=>"\nThis is just a convenient alias for pathname::unix.\n\n",examples=>[],summary=>"Path name (filename or dirname) on a Unix system"}],["pathname::unix","str"]];

1;
# ABSTRACT: Path name (filename or dirname) on a Unix system

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::unix::pathname - Path name (filename or dirname) on a Unix system

=head1 VERSION

This document describes version 0.011 of Sah::SchemaR::unix::pathname (from Perl distribution Sah-Schemas-Unix), released on 2020-05-27.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Unix>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Unix>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Unix>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
